==> rheolef_6.6.orig.tar.gz: rheolef-6.6/nfem/ptst/field_vf_expr_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
GEODIR=$SRCDIR
NPROC_MAX=${NPROC_MAX-"2"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0
#echo "    not yet (skiped)"
#exit $status

L="
$GEODIR/line-1-bdry
$GEODIR/line-2-bdry
$GEODIR/line-3-bdry
$GEODIR/line-20-bdry
$SRCDIR/carre-bamg-v2
$SRCDIR/carre-tq-10-bdry-v2
$SRCDIR/cube-5-bdry-v2
$GEODIR/cube-P-5-dom-v2
$GEODIR/my_cube_PH-5-v2
$GEODIR/my_cube_TP-5-v2
$GEODIR/my_cube_TPH-5-v2
"

for fullgeo in $L; do
 geo=`basename $fullgeo`
 dir=`dirname $fullgeo`
 for Pk in P1 P2 P3; do
   loop_mpirun "./field_vf_expr_tst $fullgeo $Pk 2>/dev/null >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
done

exit $status

==> rheolef_6.7.orig.tar.gz: rheolef-6.7/nfem/ptst/field_vf_expr_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
GEODIR=$SRCDIR
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0
#echo "    not yet (skiped)"
#exit $status

L="
$GEODIR/line-1-bdry
$GEODIR/line-2-bdry
$GEODIR/line-3-bdry
$GEODIR/line-20-bdry
$SRCDIR/carre-bamg-v2
$SRCDIR/carre-tq-10-bdry-v2
$SRCDIR/cube-5-bdry-v2
$GEODIR/cube-P-5-dom-v2
$GEODIR/my_cube_PH-5-v2
$GEODIR/my_cube_TP-5-v2
$GEODIR/my_cube_TPH-5-v2
"

for fullgeo in $L; do
 geo=`basename $fullgeo`
 dir=`dirname $fullgeo`
 for Pk in P1 P2 P3; do
   loop_mpirun "./field_vf_expr_tst $fullgeo $Pk 2>/dev/null >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
done

exit $status
